# pkn

My Pocket Knife

[![Build Status](https://github.com/1kbgz/pkn/actions/workflows/build.yaml/badge.svg?branch=main&event=push)](https://github.com/1kbgz/pkn/actions/workflows/build.yaml)
[![codecov](https://codecov.io/gh/1kbgz/pkn/graph/badge.svg?token=DK9H3BRX82)](https://codecov.io/gh/1kbgz/pkn)
[![License](https://img.shields.io/github/license/1kbgz/pkn)](https://github.com/1kbgz/pkn)
[![PyPI](https://img.shields.io/pypi/v/pkn.svg)](https://pypi.python.org/pypi/pkn)

## Overview

This library contains a collection of Python utilities and extensions for commonly used frameworks, including [pydantic](https://docs.pydantic.dev/latest/), [ccflow](https://github.com/point72/ccflow), logging, Linux utilities, etc.

### pydantic

TODO

### ccflow

TODO

### logging

TODO

> [!NOTE]
> This library was generated using [copier](https://copier.readthedocs.io/en/stable/) from the [Base Python Project Template repository](https://github.com/python-project-templates/base).
